=========================================================================
 `xoutil.future.contextlib`:mod: - Utilities for with-statement contexts
=========================================================================

.. automodule:: xoutil.future.contextlib

The main reason to use this module is to stop using the ``nested()`` function
and use the `ExitStack <contextlib.ExitStack>`:class: implementation.
